==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/el/lang.php <==
<?php
/**
 * Greek language file
 *
 * Based on DokuWiki Version rc2007-05-24 english language file
 * Original english language file contents included for reference
 *
 * @author Chris Smith <chris@jalakai.co.uk>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 */
$lang['menu']                  = 'Διαχείριση Χρηστών';
$lang['noauth']                = '(η είσοδος χρηστών δεν είναι δυνατή)';
$lang['nosupport']             = '(δεν υποστηρίζεται η διαχείριση χρηστών)';
$lang['badauth']               = 'μη επιτρεπτός μηχανισμός πιστοποίησης';
$lang['user_id']               = 'Χρήστης';
$lang['user_pass']             = 'Κωδικός';
$lang['user_name']             = 'Πλήρες όνομα';
$lang['user_mail']             = 'e-mail';
$lang['user_groups']           = 'Ομάδες';
$lang['field']                 = 'Πεδίο';
$lang['value']                 = 'Τιμή';
$lang['add']                   = 'Προσθήκη';
$lang['delete']                = 'Διαγραφή';
$lang['delete_selected']       = 'Διαγραφή επιλεγμένων χρηστών';
$lang['edit']                  = 'Τροποποίηση';
$lang['edit_prompt']           = 'Τροποποίηση χρήστη';
$lang['modify']                = 'Αποθήκευση αλλαγών';
$lang['search']                = 'Αναζήτηση';
$lang['search_prompt']         = 'Εκκίνηση αναζήτησης';
$lang['clear']                 = 'Καθαρισμός φίλτρων';
$lang['filter']                = 'Φίλτρο';
$lang['summary']               = 'Εμφάνιση χρηστών %1$d-%2$d από %3$d σχετικούς. %4$d χρήστες συνολικά.';
$lang['nonefound']             = 'Δεν βρέθηκαν σχετικοί χρήστες. %d χρήστες συνολικά.';
$lang['delete_ok']             = '%d χρήστες διεγράφησαν';
$lang['delete_fail']           = '%d χρήστες δεν διεγράφησαν.';
$lang['update_ok']             = 'Επιτυχημένη τροποποίηση προφίλ χρήστη';
$lang['update_fail']           = 'Αποτυχημένη τροποποίηση προφίλ χρήστη';
$lang['update_exists']         = 'Η αλλαγή ονόματος χρήστη απέτυχε -- το νέο όνομα χρήστη (%s) ήδη υπάρχει (τυχόν άλλες αλλαγές θα εφαρμοστούν).';
$lang['start']                 = 'αρχή';
$lang['prev']                  = 'προηγούμενα';
$lang['next']                  = 'επόμενα';
$lang['last']                  = 'τέλος';
$lang['edit_usermissing']      = 'Ο επιλεγμένος χρήστης δεν βρέθηκε. Πιθανόν να διαγράφηκε στο μεταξύ.';
$lang['user_notify']           = 'Ειδοποίηση χρήστη';
$lang['note_notify']           = 'Τα ενημερωτικά e-mails στέλνονται μόνο όταν δίνεται νέος κωδικός στον χρήστη.';
$lang['note_group']            = 'Οι νέοι χρήστες θα ανήκουν στην ομάδα (%s) αν δεν οριστεί άλλη ομάδα.';
$lang['add_ok']                = 'Επιτυχημένη εγγραφή  χρήστη';
$lang['add_fail']              = 'Η εγγραφή του χρήστη απέτυχε';
$lang['notify_ok']             = 'Εστάλη ενημερωτικό e-mail';
$lang['notify_fail']           = 'Δεν ήταν δυνατή η αποστολή του ενημερωτικού e-mail';

==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/usermanager/lang/el/lang.php <==
<?php
/**
 * Greek language file
 *
 * Based on DokuWiki Version rc2007-05-24 english language file
 * Original english language file contents included for reference
 *
 * @author Chris Smith <chris@jalakai.co.uk>
 * @author Thanos Massias <tm@thriasio.gr>
 * @author Αθανάσιος Νταής <homunculus@wana.gr>
 * @author Konstantinos Koryllos <koryllos@gmail.com>
 * @author George Petsagourakis <petsagouris@gmail.com>
 */
$lang['menu']                  = 'Διαχείριση Χρηστών';
$lang['noauth']                = '(η είσοδος χρηστών δεν είναι δυνατή)';
$lang['nosupport']             = '(δεν υποστηρίζεται η διαχείριση χρηστών)';
$lang['badauth']               = 'μη επιτρεπτός μηχανισμός πιστοποίησης';
$lang['user_id']               = 'Χρήστης';
$lang['user_pass']             = 'Κωδικός';
$lang['user_name']             = 'Πλήρες όνομα';
$lang['user_mail']             = 'e-mail';
$lang['user_groups']           = 'Ομάδες';
$lang['field']                 = 'Πεδίο';
$lang['value']                 = 'Τιμή';
$lang['add']                   = 'Προσθήκη';
$lang['delete']                = 'Διαγραφή';
$lang['delete_selected']       = 'Διαγραφή επιλεγμένων χρηστών';
$lang['edit']                  = 'Τροποποίηση';
$lang['edit_prompt']           = 'Τροποποίηση χρήστη';
$lang['modify']                = 'Αποθήκευση αλλαγών';
$lang['search']                = 'Αναζήτηση';
$lang['search_prompt']         = 'Εκκίνηση αναζήτησης';
$lang['clear']                 = 'Καθαρισμός φίλτρων';
$lang['filter']                = 'Φίλτρο';
$lang['summary']               = 'Εμφάνιση χρηστών %1$d-%2$d από %3$d σχετικούς. %4$d χρήστες συνολικά.';
$lang['nonefound']             = 'Δεν βρέθηκαν σχετικοί χρήστες. %d χρήστες συνολικά.';
$lang['delete_ok']             = '%d χρήστες διεγράφησαν';
$lang['delete_fail']           = '%d χρήστες δεν διεγράφησαν.';
$lang['update_ok']             = 'Επιτυχημένη τροποποίηση προφίλ χρήστη';
$lang['update_fail']           = 'Αποτυχημένη τροποποίηση προφίλ χρήστη';
$lang['update_exists']         = 'Η αλλαγή ονόματος χρήστη απέτυχε -- το νέο όνομα χρήστη (%s) ήδη υπάρχει (τυχόν άλλες αλλαγές θα εφαρμοστούν).';
$lang['start']                 = 'αρχή';
$lang['prev']                  = 'προηγούμενα';
$lang['next']                  = 'επόμενα';
$lang['last']                  = 'τέλος';
$lang['edit_usermissing']      = 'Ο επιλεγμένος χρήστης δεν βρέθηκε. Πιθανόν να διαγράφηκε στο μεταξύ.';
$lang['user_notify']           = 'Ειδοποίηση χρήστη';
$lang['note_notify']           = 'Τα ενημερωτικά e-mails στέλνονται μόνο όταν δίνεται νέος κωδικός στον χρήστη.';
$lang['note_group']            = 'Οι νέοι χρήστες θα ανήκουν στην ομάδα (%s) αν δεν οριστεί άλλη ομάδα.';
$lang['note_pass']             = 'Ο κωδικός θα δημιουργηθεί αυτόματα εάν το πεδίο μείνει κενό και έχει επιλεγεί η αποστολή ειδοποίησης χρήστη.';
$lang['add_ok']                = 'Επιτυχημένη εγγραφή  χρήστη';
$lang['add_fail']              = 'Η εγγραφή του χρήστη απέτυχε';
$lang['notify_ok']             = 'Εστάλη ενημερωτικό e-mail';
$lang['notify_fail']           = 'Δεν ήταν δυνατή η αποστολή του ενημερωτικού e-mail';
